/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of libosso-abook
 *
 * Copyright (C) 2008-2009 Nokia Corporation. All rights reserved.
 *
 * Contact: Joergen Scheibengruber <jorgen.scheibengruber@nokia.com>
 * Author:  Travis Reitter
 */

#ifndef __OSSO_ABOOK_MC_ACCOUNT_MODEL_H__
#define __OSSO_ABOOK_MC_ACCOUNT_MODEL_H__

#include <gtk/gtkliststore.h>
#include <libmcclient/mc-account.h>

#include "osso-abook-types.h"
#include "osso-abook-caps.h"

G_BEGIN_DECLS

/**
 * OssoABookMcAccountModelColumn:
 * @OSSO_ABOOK_MC_ACCOUNT_MODEL_COL_ACCOUNT: a #McAccount
 *
 * The columns indicies for #OssoABookMcAccountModel.
 */
typedef enum {
        OSSO_ABOOK_MC_ACCOUNT_MODEL_COL_ACCOUNT,
        OSSO_ABOOK_MC_ACCOUNT_MODEL_COL_PROTOCOL_AND_UID,
        OSSO_ABOOK_MC_ACCOUNT_MODEL_COL_ICON_NAME,
} OssoABookMcAccountModelColumn;

#define OSSO_ABOOK_TYPE_MC_ACCOUNT_MODEL \
                (osso_abook_mc_account_model_get_type ())
#define OSSO_ABOOK_MC_ACCOUNT_MODEL(obj) \
                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                 OSSO_ABOOK_TYPE_MC_ACCOUNT_MODEL, \
                 OssoABookMcAccountModel))
#define OSSO_ABOOK_MC_ACCOUNT_MODEL_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_CAST ((klass), \
                 OSSO_ABOOK_TYPE_MC_ACCOUNT_MODEL, \
                 OssoABookMcAccountModelClass))
#define OSSO_ABOOK_IS_MC_ACCOUNT_MODEL(obj) \
                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                 OSSO_ABOOK_TYPE_MC_ACCOUNT_MODEL))
#define OSSO_ABOOK_IS_MC_ACCOUNT_MODEL_CLASS(klass) \
                (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                 OSSO_ABOOK_TYPE_MC_ACCOUNT_MODEL))
#define OSSO_ABOOK_MC_ACCOUNT_MODEL_GET_CLASS(obj) \
                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                 OSSO_ABOOK_TYPE_MC_ACCOUNT_MODEL, \
                 OssoABookMcAccountModelClass))

/**
 * OssoABookMcAccountModel:
 *
 * All the fields of this structure are private to the object's
 * implementation and should never be accessed directly.
 */
struct _OssoABookMcAccountModel {
        /*< private >*/
        GtkListStore parent;
};

struct _OssoABookMcAccountModelClass {
        GtkListStoreClass parent_class;
};

GType
osso_abook_mc_account_model_get_type       (void) G_GNUC_CONST;

OssoABookMcAccountModel *
osso_abook_mc_account_model_new            (void);

const char *
osso_abook_mc_account_model_get_account_protocol
        (OssoABookMcAccountModel *model);

void
osso_abook_mc_account_model_set_account_protocol
        (OssoABookMcAccountModel *model,
         const char              *protocol);

OssoABookCapsFlags
osso_abook_mc_account_model_get_required_capabilities
        (OssoABookMcAccountModel *model);

void
osso_abook_mc_account_model_set_required_capabilities
        (OssoABookMcAccountModel *model,
         OssoABookCapsFlags       caps);

GList *
osso_abook_mc_account_model_get_allowed_accounts
        (OssoABookMcAccountModel *model);
                
void     
osso_abook_mc_account_model_set_allowed_accounts
        (OssoABookMcAccountModel *model,
         GList                   *accounts);

gboolean
osso_abook_mc_account_model_get_iter       (OssoABookMcAccountModel *model,
                                            McAccount               *account,
                                            GtkTreeIter             *iter);  

G_END_DECLS

#endif /* __OSSO_ABOOK_MC_ACCOUNT_MODEL_H__ */
